PagingQuery<T extends Encodable> class

Implemented types

Constructors

PagingQuery(T? query)
Create paging query.

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int
Max. number or returned entries.
getter/setter pair
next ↔ String
Cursor for pagination.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

simpleQuery() → PagingQuery<Encodable>

Constants

DefaultLimit → const int
Default limit