UserIdList class

Constructors

UserIdList()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
toStringList() → List<String>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(List<String> ids) → UserIdList
Create UserIdList with GetSocial IDs. ids GetSocial User Ids.
createWithProvider(List<String> ids, String providerId) → UserIdList
Create UserIdList ids and provider id. ids User Ids. providerId Provider Id.