Chat class

Describe Chat object.

Constructors

Chat.fromJSON(Map<String, dynamic> json)

Properties

avatarUrl ↔ String?
getter/setter pair
createdAt ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
lastMessage ↔ ChatMessage?
getter/setter pair
membersCount ↔ int
getter/setter pair
otherMember ↔ User
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair
updatedAt ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited