ChatMessage class

Describe ChatMessage object.

Constructors

ChatMessage.fromJSON(Map<String, dynamic> json)

Properties

attachments ↔ List<MediaAttachment>
getter/setter pair
author ↔ User
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
properties ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentAt ↔ int
getter/setter pair
text ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited