CommunitiesEntity class

Describe CommunitiesEntity object.

Constructors

CommunitiesEntity.fromJSON(Map<String, dynamic> json)

Properties

allowedActions ↔ Map<int, bool>
getter/setter pair
avatarUrl ↔ String?
getter/setter pair
followersCount ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isFollowedByMe ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair
type ↔ int
getter/setter pair

Methods

isActionAllowed(int action) → bool
Check if action is allowed. action Action to check, check CommunitiesEntityAction for possible values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited