Poll class

Describe Poll object.

Constructors

Poll.fromJSON(Map<String, dynamic> json)

Properties

allowMultipleVotes ↔ bool
getter/setter pair
endDate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
knownVoters ↔ List<UserVotes>
getter/setter pair
options ↔ List<PollOption>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalVotes ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited