PollContent class

Describe PollContent object.

Inheritance

Constructors

PollContent()

Properties

allowMultipleVotes ↔ bool
getter/setter pair
endDate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
options ↔ List<PollOptionContent>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited