PollOptionContent class

Describe PollOptionContent object.

Inheritance

Constructors

PollOptionContent()

Properties

attachment ↔ MediaAttachment?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
optionId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited