ActivitiesQuery class

Inheritance

Constructors

ActivitiesQuery(CommunitiesIds ids)

Properties

author ↔ UserId?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ids ↔ CommunitiesIds
getter/setter pair
includedComments ↔ int
getter/setter pair
labels ↔ List<String>
getter/setter pair
mentions ↔ List<UserId>
getter/setter pair
pollStatus ↔ int
getter/setter pair
properties ↔ Map<String, String>
getter/setter pair
reactionGroup ↔ String?
getter/setter pair
reactions ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTerm ↔ String?
getter/setter pair
tag ↔ String?
getter/setter pair
getter/setter pair

Methods

asAnnouncementsQuery() → AnnouncementsQuery?
byUser(UserId id) → ActivitiesQuery
includeComments(int upTo) → ActivitiesQuery
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onlyTrending(bool trending) → ActivitiesQuery
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
withLabels(List<String> labels) → ActivitiesQuery
withMentions(List<UserId> mentions) → ActivitiesQuery
withPollStatus(int status) → ActivitiesQuery
withProperties(Map<String, String> properties) → ActivitiesQuery
withTag(String tag) → ActivitiesQuery
withText(String searchTerm) → ActivitiesQuery

Operators

operator ==(Object other) → bool
The equality operator.
inherited