AddGroupMembersQuery class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
internalQuery ↔ UpdateGroupMembersQuery
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
withMemberStatus(int memberStatus) → AddGroupMembersQuery
withRole(int role) → AddGroupMembersQuery

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(String groupId, UserIdList userIdList) → AddGroupMembersQuery