GroupsQuery class

Inheritance

Constructors

GroupsQuery(String? searchTerm)

Properties

follower ↔ UserId?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ List<String>
getter/setter pair
member ↔ UserId?
getter/setter pair
properties ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTerm ↔ String?
getter/setter pair
getter/setter pair

Methods

followedBy(UserId id) → GroupsQuery
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onlyTrending(bool trending) → GroupsQuery
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
withLabels(List<String> labels) → GroupsQuery
withMember(UserId id) → GroupsQuery
withProperties(Map<String, String> properties) → GroupsQuery

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

all() → GroupsQuery
find(String searchTerm) → GroupsQuery