LabelsQuery class

Inheritance

Constructors

LabelsQuery(String? searchTerm)

Properties

follower ↔ UserId?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTerm ↔ String?
getter/setter pair
getter/setter pair

Methods

followedBy(UserId id) → LabelsQuery
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onlyTrending(bool trending) → LabelsQuery
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

all() → LabelsQuery
find(String searchTerm) → LabelsQuery