MembersQuery class

Inheritance

Constructors

MembersQuery(String groupId)

Properties

groupId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
role ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
withName(String name) → MembersQuery
withRole(int role) → MembersQuery
withStatus(int status) → MembersQuery

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

ofGroup(String groupId) → MembersQuery