RemoveGroupMembersQuery class

Inheritance

Constructors

RemoveGroupMembersQuery(UserIdList userIdList, String groupId)

Properties

groupId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIdList ↔ UserIdList
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(String groupId, UserIdList userIdList) → RemoveGroupMembersQuery