Topic class

Describe Topic object.

Constructors

Topic.fromJSON(Map<String, dynamic> json)

Properties

avatarUrl ↔ String?
getter/setter pair
createdAt ↔ int
getter/setter pair
followersCount ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isFollowedByMe ↔ bool
getter/setter pair
popularity ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ CommunitiesSettings
getter/setter pair
title ↔ String?
getter/setter pair
topicDescription ↔ String?
getter/setter pair
updatedAt ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited