CurrentUser class

Inheritance

Constructors

CurrentUser.fromJSON(Map<String, dynamic> json)

Properties

avatarUrl → String?
finalinherited
displayName → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
identities → Map<String, String>
finalinherited
isAnonymous → bool
no setterinherited
privateProperties → Map<String, String>
finalinherited
publicProperties → Map<String, String>
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
finalinherited
verified → bool
finalinherited

Methods

addIdentity(Identity identity, Function onSuccess, dynamic onConflict(ConflictUser), Function onError) → void
Adds Identity for the specified provider.
getBanInfo() → Future<BanInfo?>
Returns reason and expiration of the ban of the current user
isBanned() → Future<bool>
Returns if the current user is banned
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() → Future
Refresh current user properties.
removeIdentity(String providerId) → Future
Removes Identity for the specified provider.
toString() → String
A string representation of this object.
updateDetails(UserUpdate update) → Future
Requests a bulk change of properties for the current user.

Operators

operator ==(Object other) → bool
The equality operator.
inherited