Notifications class

Constructors

Notifications()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

arePushNotificationsEnabled() → Future<bool>
Check if Push Notifications are enabled for current user.
get(PagingQuery<NotificationsQuery> pagingQuery) → Future<PagingResult<GetSocialNotification>>
Get the list of current user's notifications.
getCount(NotificationsQuery query) → Future<int>
Get the number of current user's notifications based on the provided query.
registerDevice() → Future
Register device for Push Notifications.
send(NotificationContent content, SendNotificationTarget target) → Future
Send notification to any GetSocial user.
setOnNotificationClickedListener(dynamic listener(GetSocialNotification, NotificationContext)) → void
Set listener to be invoked when a Push Notification was clicked.
setOnNotificationReceivedListener(dynamic listener(GetSocialNotification)) → void
Set listener to be invoked when a Push Notification was received.
setOnTokenReceivedListener(dynamic listener(String)) → void
Set listener to be invoked when device was registered for Push Notifications.
setPushNotificationsEnabled(bool enabled) → Future
Enable or disable receiving Push Notifications. enabled Enable or disable Push Notifications.
setStatus(String newStatus, List<String> notificationIds) → Future
Set notification status.