NotificationButton class

Notification button object

Inheritance

Constructors

NotificationButton(String title, String actionId)
NotificationButton.fromJSON(Map<String, dynamic> json)

Properties

actionId ↔ String
Action Id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
Button title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

consume → const String
Consume action id.
ignore → const String
Ignore action id.