NotificationCustomization class

NotificationCustomization object.

Inheritance

Properties

backgroundImageConfiguration ↔ String?
Background image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor ↔ String?
Text color.
getter/setter pair
titleColor ↔ String?
Title text color.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited