SendNotificationTarget class

Notification target object.

Inheritance

Constructors

SendNotificationTarget()

Properties

hashCode → int
The hash code for this object.
no setterinherited
receiverPlaceholders ↔ List<String>
Placeholders, check NotificationReceiverPlaceholder for possible values.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIdList ↔ UserIdList?
UserIds.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited