User class

Implementers

Constructors

User.fromJSON(Map<String, dynamic> json)

Properties

avatarUrl → String?
final
displayName → String
final
hashCode → int
The hash code for this object.
no setterinherited
identities → Map<String, String>
final
isAnonymous → bool
no setter
publicProperties → Map<String, String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
final
verified → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited